# Swamix-IndiaTools

This is a Python package generated Swamix SoftEngine.

## Installation
pip install indiatools

## Usage
Please Read Docs or use autocomplete of editor (VS Code) to see individual function usage.

## License
MIT License
